package Tie::Tools;

# $Id: Tools.pm 1884 2007-10-29 21:25:10Z jonasbn $

use strict;
use vars qw($VERSION);

$VERSION = '1.07';

1;

__END__;

=head1 NAME

Tie::Tools - a collection of tying tools

=head1 DESCRIPTION

Tie::Tools consist of several modules each in their own namespace.

=over 4

=item

Tie::DeepTied

=item

Tie::Depth

=item

Tie::Func

=item

Tie::NormalArray

=item

Tie::Parent

=back

=cut

=head1 COPYRIGHT

Tie::Tools is free software and is released under the Artistic License.
See <http://www.perl.com/language/misc/Artistic.html> for details.

=head1 AUTHOR

This is originally the work of Ariel Brosh, a member of Israel.pm and
author of several contributions to CPAN. He has unfortunately passed
away and have left behind several Perl modules where this is just one
of them.

I volunteered to contribute further to the development of the modules,
but it is still kept under the name of Ariel Brosh - the original
author.

Jonas B. Nielsen <jonasbn@cpan.org>

=head1 ACKNOWLEDGEMENTS

- patch from Brian Dowling resulting in release 1.06

=cut
